@@ -1,80 +1,3 @@
-FUNCTION random_normal() RESULT (ran_norm)
-
-! Adapted from the following Fortran 77 code
-!      ALGORITHM 712, COLLECTED ALGORITHMS FROM ACM.
-!      THIS WORK PUBLISHED IN TRANSACTIONS ON MATHEMATICAL SOFTWARE,
-!      VOL. 18, NO. 4, DECEMBER, 1992, PP. 434-435.
-
-!  The function random_normal() returns a normally distributed pseudo-random
-!  number with zero mean and unit variance.   This version uses the default
-!  uniform random number generator which is in your fortran library.
-
-!  The algorithm uses the ratio of uniforms method of A.J. Kinderman
-!  and J.F. Monahan augmented with quadratic bounding curves.
-
-!  Fortran 90 version by Alan Miller (alan @ mel.dms.csiro.au)
-
-IMPLICIT NONE
-REAL :: ran_norm
-
-!     Local variables
-REAL, PARAMETER :: s = 0.449871, t = -0.386595, a = 0.19600, b = 0.25472,   &
-                   half = 0.5, r1 = 0.27597, r2 = 0.27846
-REAL            :: u, v, x, y, q
-
-!     Generate P = (u,v) uniform in rectangle enclosing acceptance region
-
-DO
-  CALL RANDOM_NUMBER(u)
-  CALL RANDOM_NUMBER(v)
-  v = 1.7156 * (v - half)
-
-!     Evaluate the quadratic form
-  x = u - s
-  y = ABS(v) - t
-  q = x**2 + y*(a*y - b*x)
-
-!     Accept P if inside inner ellipse
-  IF (q < r1) EXIT
-!     Reject P if outside outer ellipse
-  IF (q > r2) CYCLE
-!     Reject P if outside acceptance region
-  IF (v**2 < -4.0*LOG(u)*u**2) EXIT
-END DO
-
-!     Return ratio of P's coordinates as the normal deviate
-ran_norm = v/u
-RETURN
-
-END FUNCTION random_normal
-
-
-! choose k subjects from n randomly
-! omega(i) = 1 if i'th subject is chosen, 0 if not
-SUBROUTINE RanSample (omega, n, k)
-    IMPLICIT NONE
-    ! - - - arg types - - -
-    INTEGER :: n
-    INTEGER :: k
-    INTEGER :: omega (n)
-    ! - - - local declarations - - -
-    integer :: i,j
-    integer :: index(n)
-    double precision :: u    ! uniform random variable
-    integer :: temp
-
-    omega = 0
-    index = (/ (i,i=1,n) /)
-    do i=1,k
-        call random_number(u)
-        j = int(float(n-i+1)*u) + i
-        temp = index(i)
-        index(i) = index(j)
-        index(j) = temp
-    end do
-    omega(index(1:k)) = 1
-END SUBROUTINE RanSample
-
 
 subroutine inverse(a,c,n)
 !============================================================
